==> unicon-3.3.0-cp35-cp35m-macosx_10_10_x86_64.whl: unicon/plugins/iosxr/patterns.py <==
__copyright__ = "# Copyright (c) 2016 by cisco Systems, Inc. All rights reserved."
__author__ = "Syed Raza <syedraza@cisco.com>"


from unicon.plugins.generic.patterns import GenericPatterns

# This module contains all the patterns required in the IOSXR implementation.

class IOSXRPatterns(GenericPatterns):
    def __init__(self):
        super().__init__()
        self.enable_prompt = r'^(.*?)RP/\S+(%N|ios|xr)\s?#\s?$'
        # don't use hostname match in config prompt - hostname may be truncated
        # see CSCve48115 and CSCve51502
        self.run_prompt = r'(^.*?)\[xr-vm_.*:~\]\s?\$\s?$'
        self.config_prompt = r'^(.*?)RP/\S+\(config.*\)\s?#\s?$'
        self.telnet_prompt = r'^.*Escape character is.*$'
        self.username_prompt = r'^.*([Uu]sername|[Ll]ogin):\s*$'
        self.password_prompt = r'^.*([Pp]assword|Enter secret(\sagain)?): ?$'
        self.commit_changes_prompt = r'Uncommitted changes found, commit them'
        self.logout_prompt = r'^.*Press RETURN to get started\..*$'
        self.commit_replace_prompt = r'Do you wish to proceed?'
        self.admin_prompt = r'(^.*?)sysadmin-vm:0_(.*)\s?#\s?$'
        self.admin_conf_prompt = r'(^.*?)sysadmin-vm:0_(.*)\(config.*\)\s?#\s?$'
        self.admin_run_prompt = r'(^.*?)\[sysadmin-vm:0_.*:~\]\s?\$\s?$'
        self.unreachable_prompt = r'apples are green but oranges are red'
        self.configuration_failed_message = r'^.*Please issue \'show configuration failed \[inheritance\].*$'
        self.standby_prompt = r'^.*This \(D\)RP Node is not ready or active for login \/configuration.*$'
        self.rp_extract_status = r'^\d+\s+(\w+)\s+\-?\d+.*$'
        self.confirm_y_prompt = r'\[confirm\]\s*\[y/n\]'

==> unicon-19.6-cp35-cp35m-macosx_10_10_x86_64.whl: unicon/plugins/iosxr/patterns.py <==
__copyright__ = "# Copyright (c) 2016 by cisco Systems, Inc. All rights reserved."
__author__ = "Syed Raza <syedraza@cisco.com>"


from unicon.plugins.generic.patterns import GenericPatterns

# This module contains all the patterns required in the IOSXR implementation.

class IOSXRPatterns(GenericPatterns):
    def __init__(self):
        super().__init__()
        self.enable_prompt = r'^(.*?)RP/\d+/\S+/\S+\d+:(%N|ios|xr)\s?#\s?$'
        # don't use hostname match in config prompt - hostname may be truncated
        # see CSCve48115 and CSCve51502
        self.run_prompt = r'^(.*?)(?:\[xr-vm_.*:([\s\S]+)?\]\s?\$\s?|[\r\n]+\s?#\s?)$'
        self.config_prompt = r'^(.*?)RP/\S+\(config.*\)\s?#\s?$'
        self.telnet_prompt = r'^.*Escape character is.*$'
        self.username_prompt = r'^.*([Uu]sername|[Ll]ogin):\s*$'
        self.password_prompt = r'^.*[Pp]assword:\s?$'
        self.secret_password_prompt = r'^.*Enter secret(\sagain)?:\s?$'
        self.commit_changes_prompt = r'Uncommitted changes found, commit them'
        self.logout_prompt = r'^.*Press RETURN to get started\..*$'
        self.commit_replace_prompt = r'Do you wish to proceed?'
        self.admin_prompt = r'^(.*?)(?:sysadmin-vm:0_(.*)\s?#\s?$|RP/\S+\(admin\)\s?#\s?)$'
        self.admin_conf_prompt = r'^(.*?)(?:sysadmin-vm:0_(.*)\(config.*\)\s?#\s?|RP/\S+\(admin-config\)\s?#\s?)$'
        self.admin_run_prompt = r'^(.*?)(?:\[sysadmin-vm:0_.*:([\s\S]+)?\]\s?\$\s?|[\r\n]+\s?#\s?)$'
        self.unreachable_prompt = r'apples are green but oranges are red'
        self.configuration_failed_message = r'^.*Please issue \'show configuration failed \[inheritance\].*$'
        self.standby_prompt = r'^.*This \(D\)RP Node is not ready or active for login \/configuration.*$'
        self.rp_extract_status = r'^\d+\s+(\w+)\s+\-?\d+.*$'
        self.confirm_y_prompt = r"\[confirm( with only 'y' or 'n')?\]\s*\[y/n\]"
